pub(super) async fn dispose_webview_panel_impl(
env: &MountainEnvironment,
handle: String,
) -> Result<(), CommonError>Expand description
Disposes a Webview panel and cleans up all associated resources.
pub(super) async fn dispose_webview_panel_impl(
env: &MountainEnvironment,
handle: String,
) -> Result<(), CommonError>Disposes a Webview panel and cleans up all associated resources.